==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/AKSDeploymentPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Class for AKSDeployment Properties.
 * @property aksClusterName Gets or sets the AKS cluster name.
 * @property resourceGroup Gets or sets the resource group of the resource.
 * @property subscriptionId Gets or sets the subscription id of the resource.
 * @property tenantId Gets or sets the tenant id.
 */
public data class AKSDeploymentPropertiesArgs(
    public val aksClusterName: Output<String>? = null,
    public val resourceGroup: Output<String>? = null,
    public val subscriptionId: Output<String>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs.builder()
            .aksClusterName(aksClusterName?.applyValue({ args0 -> args0 }))
            .resourceGroup(resourceGroup?.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AKSDeploymentPropertiesArgs].
 */
@PulumiTagMarker
public class AKSDeploymentPropertiesArgsBuilder internal constructor() {
    private var aksClusterName: Output<String>? = null

    private var resourceGroup: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Gets or sets the AKS cluster name.
     */
    @JvmName("rvjxurcmbyfqqdgj")
    public suspend fun aksClusterName(`value`: Output<String>) {
        this.aksClusterName = value
    }

    /**
     * @param value Gets or sets the resource group of the resource.
     */
    @JvmName("qnrrbccconlxjwcm")
    public suspend fun resourceGroup(`value`: Output<String>) {
        this.resourceGroup = value
    }

    /**
     * @param value Gets or sets the subscription id of the resource.
     */
    @JvmName("fxavxmcchrgypado")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value Gets or sets the tenant id.
     */
    @JvmName("ueidedsvhxgnfeox")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Gets or sets the AKS cluster name.
     */
    @JvmName("sscinoebylbpvnma")
    public suspend fun aksClusterName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.aksClusterName = mapped
    }

    /**
     * @param value Gets or sets the resource group of the resource.
     */
    @JvmName("ysuufstsytfwgvbc")
    public suspend fun resourceGroup(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroup = mapped
    }

    /**
     * @param value Gets or sets the subscription id of the resource.
     */
    @JvmName("jjeclxvqusglwwhf")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value Gets or sets the tenant id.
     */
    @JvmName("nenjwfmefduftbya")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): AKSDeploymentPropertiesArgs = AKSDeploymentPropertiesArgs(
        aksClusterName = aksClusterName,
        resourceGroup = resourceGroup,
        subscriptionId = subscriptionId,
        tenantId = tenantId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/AKSDeploymentPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Class for AKSDeployment Properties.
 * @property aksClusterName Gets or sets the AKS cluster name.
 * @property resourceGroup Gets or sets the resource group of the resource.
 * @property subscriptionId Gets or sets the subscription id of the resource.
 * @property tenantId Gets or sets the tenant id.
 */
public data class AKSDeploymentPropertiesArgs(
    public val aksClusterName: Output<String>? = null,
    public val resourceGroup: Output<String>? = null,
    public val subscriptionId: Output<String>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.AKSDeploymentPropertiesArgs.builder()
            .aksClusterName(aksClusterName?.applyValue({ args0 -> args0 }))
            .resourceGroup(resourceGroup?.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AKSDeploymentPropertiesArgs].
 */
@PulumiTagMarker
public class AKSDeploymentPropertiesArgsBuilder internal constructor() {
    private var aksClusterName: Output<String>? = null

    private var resourceGroup: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Gets or sets the AKS cluster name.
     */
    @JvmName("puuqrfstwthaqysv")
    public suspend fun aksClusterName(`value`: Output<String>) {
        this.aksClusterName = value
    }

    /**
     * @param value Gets or sets the resource group of the resource.
     */
    @JvmName("qnhgxkqrhdvgllhf")
    public suspend fun resourceGroup(`value`: Output<String>) {
        this.resourceGroup = value
    }

    /**
     * @param value Gets or sets the subscription id of the resource.
     */
    @JvmName("mrxiscqdxdncnbtj")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value Gets or sets the tenant id.
     */
    @JvmName("dksywucvquxvjebr")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Gets or sets the AKS cluster name.
     */
    @JvmName("hnhckltprklyrlxq")
    public suspend fun aksClusterName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.aksClusterName = mapped
    }

    /**
     * @param value Gets or sets the resource group of the resource.
     */
    @JvmName("eepablnmlsjsuuqk")
    public suspend fun resourceGroup(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroup = mapped
    }

    /**
     * @param value Gets or sets the subscription id of the resource.
     */
    @JvmName("upucwcqtxjndhtxc")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value Gets or sets the tenant id.
     */
    @JvmName("wuvoojhjhbhmsnue")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): AKSDeploymentPropertiesArgs = AKSDeploymentPropertiesArgs(
        aksClusterName = aksClusterName,
        resourceGroup = resourceGroup,
        subscriptionId = subscriptionId,
        tenantId = tenantId,
    )
}
